#!/usr/bin/env bash

# shell script to launch LustreC docker, mainly for launching tests
# see the usage function for more explanations

# usage function
usage () {
    echo "Usage: " $0 " [-h|--help] [-i|--id ID] [-t|--tmp TMP_DIR] [options passed to docker]"
    echo "  Run a docker instance named \"lustrec_docker\" built with image " $CONTAINER_ID " by default."
    echo "  Available options:"
    echo "  - [-i|--id ID]       | change container image ID"
    echo "  - [-t|--tmp TMP_DIR] | change binding for /tmp dir in container. Default to /tmp"
    exit 1
}

# default values
CONTAINER_ID=gitlab-registry.isae-supaero.fr/lustrec/lustrec/lustrec-run:latest
TMP_DIR=/tmp

# check if docker is available
command -v docker >/dev/null 2>&1 || { \
        echo >&2 "docker is required but could not be found.  Aborting."; \
        echo >&2 "To setup Docker: https://docs.docker.com/engine/getstarted/step_one/"; \
        exit 1; }

# use getopt to get arguments
TEMP=$(getopt -o 'hi:t:' --long 'help,id:,tmp:' -n 'rundocker.sh' -- "$@")

eval set -- "$TEMP"
unset TEMP

# main loop to get arguments
while true; do
    case "$1" in
        '-h'|'--help')
            usage
        ;;
        '-i'|'--id')
            CONTAINER_ID="$2"
            shift 2
            continue
        ;;
        '-t'|'--tmp')
            TMP_DIR="$2"
            shift 2
            continue
        ;;
        *)
            shift
            break
        ;;
    esac
done

# launch docker
docker run -it --rm \
       --name "lustrec-from-${CONTAINER_ID}" \
       -v ${TMP_DIR}:/tmp -v ${PWD}:/home/opam/lustrec \
       ${CONTAINER_ID} $@
